@@ -33,7 +33,7 @@ static int nvidia_dev_open(
     struct cdev *dev,
     int oflags,
     int devtype,
-    d_thread_t *td
+    struct thread *td
 )
 {
     int status;
@@ -87,7 +87,7 @@ static int nvidia_dev_ioctl(
     u_long cmd,
     caddr_t data,
     int fflag,
-    d_thread_t *td
+    struct thread *td
 )
 {
     int status;
@@ -112,7 +112,7 @@ static int nvidia_dev_ioctl(
 static int nvidia_dev_poll(
     struct cdev *dev,
     int events,
-    d_thread_t *td
+    struct thread *td
 )
 {
     struct nvidia_filep *filep;
