@@ -110,14 +110,16 @@ fail:
 static void nvidia_pci_disable_serr(device_t dev)
 {
     NvU16 word;
-    word = (os_pci_read_word(dev, PCIR_COMMAND) & ~PCIM_CMD_SERRESPEN);
+    os_pci_read_word(dev, PCIR_COMMAND, &word);
+    word &= ~PCIM_CMD_SERRESPEN;
     os_pci_write_word(dev, PCIR_COMMAND, word);
 }
 
 static void nvidia_pci_enable_intx(device_t dev)
 {
     NvU16 word;
-    word = (os_pci_read_word(dev, PCIR_COMMAND) & ~PCIM_CMD_INTXDIS);
+    os_pci_read_word(dev, PCIR_COMMAND, &word);
+    word &= ~PCIM_CMD_INTXDIS;
     os_pci_write_word(dev, PCIR_COMMAND, word);
 }
 
@@ -140,7 +142,7 @@ void nvidia_pci_check_config_space(
         return;
     }
 
-    word = os_pci_read_word(dev, PCIR_COMMAND);
+    os_pci_read_word(dev, PCIR_COMMAND, &word);
 
     if ((word & PCIM_CMD_BUSMASTEREN) == 0)
         pci_enable_busmaster(dev);
@@ -161,7 +163,7 @@ void nvidia_pci_check_config_space(
             nv_aperture_t *BAR = &nv->bars[i];
             if (BAR->offset == 0) continue;
 
-            BAR_low = os_pci_read_dword(dev, BAR->offset);
+            os_pci_read_dword(dev, BAR->offset, &BAR_low);
             if ((BAR_low & NVRM_PCICFG_BAR_ADDR_MASK) != 
                 (BAR->address & 0xffffffff))
                 os_pci_write_dword(dev, BAR->offset, 
@@ -171,7 +173,7 @@ void nvidia_pci_check_config_space(
                     != NVRM_PCICFG_BAR_MEMTYPE_64BIT)
                 continue;
 
-            BAR_high = os_pci_read_dword(dev, BAR->offset + 4);
+            os_pci_read_dword(dev, BAR->offset + 4, &BAR_high);
             if ((BAR_low & NVRM_PCICFG_BAR_ADDR_MASK) == BAR->address
                     && BAR_high == 0)
                 continue;
@@ -253,16 +255,16 @@ int nvidia_pci_attach(device_t dev)
 
     for (i = 0, j = 0; i < NVRM_PCICFG_NUM_BARS && j < NV_GPU_NUM_BARS; i++) {
         NvU8 offset = NVRM_PCICFG_BAR_OFFSET(i);
-        BAR_low = os_pci_read_dword(dev, offset);
+        os_pci_read_dword(dev, offset, &BAR_low);
         os_pci_write_dword(dev, offset, 0xffffffff);
-        req = os_pci_read_dword(dev, offset);
+        os_pci_read_dword(dev, offset, &req);
         if ((req != 0) /* implemented */ && (req & NVRM_PCICFG_BAR_REQTYPE_MASK)
                 == NVRM_PCICFG_BAR_REQTYPE_MEMORY) {
             sc->nv_state->bars[j].offset = offset;
             sc->BAR_rids[j] = offset; 
             if ((req & NVRM_PCICFG_BAR_MEMTYPE_MASK) == NVRM_PCICFG_BAR_MEMTYPE_64BIT)
             {
-                BAR_high = os_pci_read_dword(dev, offset + 4);
+                os_pci_read_dword(dev, offset + 4, (NvU32 *)&BAR_high);
                 sc->nv_state->bars[j].address |= (BAR_high << 32);
                 i++;
             }
