@@ -375,15 +375,19 @@ typedef NvS16                                                       NvSFXP4_12;
 typedef NvS16                                                        NvSFXP8_8;
 typedef NvS32                                                       NvSFXP8_24;
 typedef NvS32                                                      NvSFXP16_16;
+typedef NvS32                                                      NvSFXP20_12;
 typedef NvS32                                                       NvSFXP24_8;
 typedef NvS32                                                       NvSFXP27_5;
 typedef NvS32                                                       NvSFXP29_3;
+typedef NvS32                                                       NvSFXP31_1;
 
 typedef NvU16                                                       NvUFXP4_12;
 typedef NvU32                                                       NvUFXP8_24;
+typedef NvU32                                                       NvUFXP9_23;
 typedef NvU32                                                      NvUFXP16_16;
 typedef NvU32                                                      NvUFXP20_12;
 typedef NvU32                                                       NvUFXP24_8;
+typedef NvU32                                                       NvUFXP25_7;
 
 /*!
  * Utility macros used in converting between signed integers and fixed-point
@@ -449,8 +453,9 @@ typedef NvU32                                                       NvUFXP24_8;
                     ((NvUFXP##x##_##y) (fxp)))))
 
 #define NV_TYPES_UFXP_X_Y_TO_U32_ROUNDED(x, y, fxp)                           \
-    NV_TYPES_UFXP_X_Y_TO_U32(x, y, ((fxp) +                                   \
-        BIT(DRF_SHIFT(NV_TYPES_FXP_FRACTIONAL_MSB((x), (y))))))
+    (NV_TYPES_UFXP_X_Y_TO_U32(x, y, (fxp)) +                                  \
+        !!DRF_VAL(_TYPES, _FXP, _FRACTIONAL_MSB((x), (y)),                    \
+            ((NvUFXP##x##_##y) (fxp))))
 
 /*!
  * Signed:
@@ -476,10 +481,70 @@ typedef NvU32                                                       NvUFXP24_8;
                     NV_TYPES_SFXP_S32_SIGN_EXTENSION_POSITIVE((x), (y))))))
 
 #define NV_TYPES_SFXP_X_Y_TO_S32_ROUNDED(x, y, fxp)                           \
-    NV_TYPES_SFXP_X_Y_TO_S32(x, y, ((fxp) +                                   \
-        BIT(DRF_SHIFT(NV_TYPES_FXP_FRACTIONAL_MSB((x), (y))))))
+    (NV_TYPES_SFXP_X_Y_TO_S32(x, y, (fxp)) +                                  \
+        !!DRF_VAL(_TYPES, _FXP, _FRACTIONAL_MSB((x), (y)),                    \
+            ((NvSFXP##x##_##y) (fxp))))
 
 
+/*!
+ * Macros representing the single-precision IEEE 754 floating point format for
+ * "binary32", also known as "single" and "float".
+ *
+ * http://en.wikipedia.org/wiki/Single_precision_floating-point_format
+ *
+ * _SIGN
+ *     Single bit representing the sign of the number.
+ * _EXPONENT
+ *     Unsigned 8-bit number representing the exponent value by which to scale
+ *     the mantissa.
+ *     _BIAS - The value by which to offset the exponent to account for sign.
+ * _MANTISSA
+ *     Explicit 23-bit significand of the value.  When exponent != 0, this is an
+ *     implicitly 24-bit number with a leading 1 prepended.  This 24-bit number
+ *     can be conceptualized as FXP 9.23.
+ *
+ * With these definitions, the value of a floating point number can be
+ * calculated as:
+ *     (-1)^(_SIGN) *
+ *         2^(_EXPONENT - _EXPONENT_BIAS) *
+ *         (1 + _MANTISSA / (1 << 23))
+ */
+#define NV_TYPES_SINGLE_SIGN                                               31:31
+#define NV_TYPES_SINGLE_SIGN_POSITIVE                                 0x00000000
+#define NV_TYPES_SINGLE_SIGN_NEGATIVE                                 0x00000001
+#define NV_TYPES_SINGLE_EXPONENT                                           30:23
+#define NV_TYPES_SINGLE_EXPONENT_ZERO                                 0x00000000
+#define NV_TYPES_SINGLE_EXPONENT_BIAS                                 0x0000007F
+#define NV_TYPES_SINGLE_MANTISSA                                            22:0
+
+
+/*!
+ * Helper macro to return a IEEE 754 single-precision value's mantissa as an
+ * unsigned FXP 9.23 value.
+ *
+ * @param[in] single   IEEE 754 single-precision value to manipulate.
+ *
+ * @return IEEE 754 single-precision values mantissa represented as an unsigned
+ *     FXP 9.23 value.
+ */
+#define NV_TYPES_SINGLE_MANTISSA_TO_UFXP9_23(single)                           \
+    ((NvUFXP9_23)(FLD_TEST_DRF(_TYPES, _SINGLE, _EXPONENT, _ZERO, single) ?    \
+                    NV_TYPES_U32_TO_UFXP_X_Y(9, 23, 0) :                       \
+                    (NV_TYPES_U32_TO_UFXP_X_Y(9, 23, 1) +                      \
+                        DRF_VAL(_TYPES, _SINGLE, _MANTISSA, single))))
+
+/*!
+ * Helper macro to return an IEEE 754 single-precision value's exponent,
+ * including the bias.
+ *
+ * @param[in] single   IEEE 754 single-precision value to manipulate.
+ *
+ * @return Signed exponent value for IEEE 754 single-precision.
+ */
+#define NV_TYPES_SINGLE_EXPONENT_BIASED(single)                                \
+    ((NvS32)(DRF_VAL(_TYPES, _SINGLE, _EXPONENT, single) -                     \
+        NV_TYPES_SINGLE_EXPONENT_BIAS))
+
 #include "xapi-sdk.h"       /* XAPIGEN sdk macros for C */
 
 
