@@ -72,7 +72,7 @@ typedef struct
 NvU32       NV_API_CALL  os_get_page_size            (void);
 NvU64       NV_API_CALL  os_get_page_mask            (void);
 NvU64       NV_API_CALL  os_get_system_memory_size   (void);
-RM_STATUS   NV_API_CALL  os_alloc_mem                (void **, NvU32);
+RM_STATUS   NV_API_CALL  os_alloc_mem                (void **, NvU64);
 void        NV_API_CALL  os_free_mem                 (void *);
 RM_STATUS   NV_API_CALL  os_get_current_time         (NvU32 *, NvU32 *);
 RM_STATUS   NV_API_CALL  os_delay                    (NvU32);
@@ -104,8 +104,8 @@ void        NV_API_CALL  os_unmap_user_space         (void *, NvU64, void *);
 RM_STATUS   NV_API_CALL  os_flush_cpu_cache          (void);
 RM_STATUS   NV_API_CALL  os_flush_user_cache         (NvU64, NvU64, NvU64, NvU64, NvU32);
 void        NV_API_CALL  os_flush_cpu_write_combine_buffer(void);
-RM_STATUS   NV_API_CALL  os_set_mem_range            (NvU64, NvU64, NvU32);
-RM_STATUS   NV_API_CALL  os_unset_mem_range          (NvU64, NvU64);
+RM_STATUS   NV_API_CALL  os_set_mem_range            (NvU64, NvU64, NvU32, NvS32 *);
+RM_STATUS   NV_API_CALL  os_unset_mem_range          (NvU64, NvU64, NvS32);
 BOOL        NV_API_CALL  os_pci_device_present       (NvU16, NvU16);
 NvU8        NV_API_CALL  os_io_read_byte             (NvU32);
 NvU16       NV_API_CALL  os_io_read_word             (NvU32);
